==> haskell-turtle-1.4.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: turtle
version: 1.4.3
id: turtle-1.4.3-FzOIlT2qLey6ePDCCKHIb2
key: turtle-1.4.3-FzOIlT2qLey6ePDCCKHIb2
license: BSD3
copyright: 2015 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.
    .
    Features include:
    .
    * Batteries included: Command an extended suite of predefined utilities
    .
    * Interoperability: You can still run external shell commands
    .
    * Portability: Works on Windows, OS X, and Linux
    .
    * Exception safety: Safely acquire and release resources
    .
    * Streaming: Transform or fold command output in constant space
    .
    * Patterns: Use typed regular expressions that can parse structured values
    .
    * Formatting: Type-safe @printf@-style text formatting
    .
    * Modern: Supports @text@ and @system-filepath@
    .
    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide
    .
    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.
category: System
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial
hidden-modules: Turtle.Internal
abi: 71644350ee68edcb7c6b181636c7ecdd
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/turtle-1.4.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/turtle-1.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/turtle-1.4.3
hs-libraries: HSturtle-1.4.3-FzOIlT2qLey6ePDCCKHIb2
depends:
    base-4.10.0.0 ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc bytestring-0.10.8.2
    clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg directory-1.3.0.2
    foldl-1.3.2-BGRT7HjGiX35g2tr0jImlB
    hostname-1.0-ITdZPWe9XL7105h6B80pVP
    managed-1.0.5-AtVs0QEjn5cnY7UxRWyLE process-1.6.1.0
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB
    system-fileio-0.3.16.3-8q55Bl57w6jJvYSIouKL6q
    stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    optional-args-1.0.1-Ca5saO7bmrq5UodVMXfAMM
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp unix-2.7.2.2
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk=4ede995ab9d7732b35861222dcc02e54
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=877e0732f418402f16d143a5b45ef88e
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg=629a53874d6ef84a20e99d8baabc3f05
             directory-1.3.0.2=3638cd3d85711234b23f0c0ec04058d3
             foldl-1.3.2-BGRT7HjGiX35g2tr0jImlB=4cbb69f455641c9613eb2fe512630562
             hostname-1.0-ITdZPWe9XL7105h6B80pVP=9094cd2097c7fcd872b29f129bfc4128
             managed-1.0.5-AtVs0QEjn5cnY7UxRWyLE=1c70fcf66601df390d68a65ee9fe9ec0
             process-1.6.1.0=d01a8ca2c6610f40dfd0fe25f50afb10
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=f833729171d8aeedacf984b736ec248c
             system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB=806b1ef3b0e09f935a24622f0daf92e9
             system-fileio-0.3.16.3-8q55Bl57w6jJvYSIouKL6q=c344e0fe91ac631154c1fd40b453a0bf
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=b0109b1e29ac5bcdebe44e0ece53e651
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=20b0c141fa697847735440856ee60c67
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=6e274c406ae75d555ff178d9e00225b0
             optional-args-1.0.1-Ca5saO7bmrq5UodVMXfAMM=1ae2c778c061b266a30baa9476faaea7
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=c3087b497fbb9a1a0b9e1db4ff794ff4
             unix-2.7.2.2=65f42a53c0d1c7bb4ba5966ba6a43504
haddock-interfaces: /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html: /usr/share/doc/haskell-turtle/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-turtle-1.4.4-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: turtle
version: 1.4.4
id: turtle-1.4.4-CVPirABnxvVGPMofb8kd0E
key: turtle-1.4.4-CVPirABnxvVGPMofb8kd0E
license: BSD3
copyright: 2015 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.
    .
    Features include:
    .
    * Batteries included: Command an extended suite of predefined utilities
    .
    * Interoperability: You can still run external shell commands
    .
    * Portability: Works on Windows, OS X, and Linux
    .
    * Exception safety: Safely acquire and release resources
    .
    * Streaming: Transform or fold command output in constant space
    .
    * Patterns: Use typed regular expressions that can parse structured values
    .
    * Formatting: Type-safe @printf@-style text formatting
    .
    * Modern: Supports @text@ and @system-filepath@
    .
    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide
    .
    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.
category: System
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial
hidden-modules: Turtle.Internal
abi: 0fce9a1cf3cfe36569c2fd7d77e08d4e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/turtle-1.4.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/turtle-1.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/turtle-1.4.4
hs-libraries: HSturtle-1.4.4-CVPirABnxvVGPMofb8kd0E
depends:
    base-4.10.0.0 ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc bytestring-0.10.8.2
    clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg directory-1.3.0.2
    foldl-1.3.2-BGRT7HjGiX35g2tr0jImlB
    hostname-1.0-ITdZPWe9XL7105h6B80pVP
    managed-1.0.5-AtVs0QEjn5cnY7UxRWyLE process-1.6.1.0
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB
    system-fileio-0.3.16.3-8q55Bl57w6jJvYSIouKL6q
    stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    optional-args-1.0.1-Ca5saO7bmrq5UodVMXfAMM
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp unix-2.7.2.2
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk=4ede995ab9d7732b35861222dcc02e54
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=877e0732f418402f16d143a5b45ef88e
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg=629a53874d6ef84a20e99d8baabc3f05
             directory-1.3.0.2=3638cd3d85711234b23f0c0ec04058d3
             foldl-1.3.2-BGRT7HjGiX35g2tr0jImlB=4cbb69f455641c9613eb2fe512630562
             hostname-1.0-ITdZPWe9XL7105h6B80pVP=9094cd2097c7fcd872b29f129bfc4128
             managed-1.0.5-AtVs0QEjn5cnY7UxRWyLE=1c70fcf66601df390d68a65ee9fe9ec0
             process-1.6.1.0=d01a8ca2c6610f40dfd0fe25f50afb10
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=f833729171d8aeedacf984b736ec248c
             system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB=806b1ef3b0e09f935a24622f0daf92e9
             system-fileio-0.3.16.3-8q55Bl57w6jJvYSIouKL6q=c344e0fe91ac631154c1fd40b453a0bf
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=b0109b1e29ac5bcdebe44e0ece53e651
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=20b0c141fa697847735440856ee60c67
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=6e274c406ae75d555ff178d9e00225b0
             optional-args-1.0.1-Ca5saO7bmrq5UodVMXfAMM=1ae2c778c061b266a30baa9476faaea7
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=c3087b497fbb9a1a0b9e1db4ff794ff4
             unix-2.7.2.2=65f42a53c0d1c7bb4ba5966ba6a43504
haddock-interfaces: /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html: /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
